FSKit class

Constructors

FSKit.start(String envId, String apiKey, String visitorId, Function onSdkReady)

Properties

apiKey String
final
envId String
final
hashCode int
The hash code for this object.
no setterinherited
onSdkReady Function
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visitorId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited